diff --git a/src/Controller/ReadLogFileController.php b/src/Controller/ReadLogFileController.php
index 263ab111f6075364ef9e8b115378e312ebadafbf..809cf6439f59dbc6117f3a7d180a7702f643a785 100644
--- a/src/Controller/ReadLogFileController.php
+++ b/src/Controller/ReadLogFileController.php
@@ -3,6 +3,7 @@
 namespace App\Controller;
 use App\Actions\ReadLogFileAction;
 use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
+use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpFoundation\Response;
 use Symfony\Component\Routing\Attribute\Route;
 
@@ -13,15 +14,16 @@ class ReadLogFileController extends AbstractController
      * проверяет, что файл существует и выводит пользователю весь контент файла
      * (файл можешь создать любой)
      *
-     * @param string $filePath путь до файла
-     * @return Response */
-    #[Route('/read/{filePath}', name: 'app_read_log_file', methods: ['GET'])]
-    public function index(string $filePath, ReadLogFileAction $action): Response
+     * @param Request $request
+     * @param ReadLogFileAction $action
+     * @return Response
+     */
+    #[Route('/read', name: 'app_read_log_file', methods: ['POST'])]
+    public function index(Request $request, ReadLogFileAction $action): Response
     {
-        try {
-            return new Response($action->act($filePath));
-        } catch (\Exception $exception) {
-            return new Response('Searching file not found :/', 422);
-        }
+        $file = $request->files->get("File");
+        return new Response($action->act($file->getPathname()));
     }
-}
+
+    }
+